aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/gregtech/api/interfaces/fluid
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/gregtech/api/interfaces/fluid')
-rw-r--r--src/main/java/gregtech/api/interfaces/fluid/IGTFluid.java14
-rw-r--r--src/main/java/gregtech/api/interfaces/fluid/IGTFluidBuilder.java (renamed from src/main/java/gregtech/api/interfaces/fluid/IGT_FluidBuilder.java)62
-rw-r--r--src/main/java/gregtech/api/interfaces/fluid/IGTRegisteredFluid.java (renamed from src/main/java/gregtech/api/interfaces/fluid/IGT_RegisteredFluid.java)38
-rw-r--r--src/main/java/gregtech/api/interfaces/fluid/IGT_Fluid.java14
4 files changed, 64 insertions, 64 deletions
diff --git a/src/main/java/gregtech/api/interfaces/fluid/IGTFluid.java b/src/main/java/gregtech/api/interfaces/fluid/IGTFluid.java
new file mode 100644
index 0000000000..b3765d37db
--- /dev/null
+++ b/src/main/java/gregtech/api/interfaces/fluid/IGTFluid.java
@@ -0,0 +1,14 @@
+package gregtech.api.interfaces.fluid;
+
+import net.minecraftforge.fluids.FluidRegistry;
+
+@SuppressWarnings("unused") // API might legitimately expose unused methods within this local project's scope
+public interface IGTFluid {
+
+ /**
+ * Adds this {@link IGTFluid} to the {@link FluidRegistry} and internally-implemented registrations
+ *
+ * @return {@link IGTRegisteredFluid} The GregTech registered fluid
+ */
+ IGTRegisteredFluid addFluid();
+}
diff --git a/src/main/java/gregtech/api/interfaces/fluid/IGT_Fluid.java b/src/main/java/gregtech/api/interfaces/fluid/IGT_Fluid.java
deleted file mode 100644
index 7c8b2b3f11..0000000000
--- a/src/main/java/gregtech/api/interfaces/fluid/IGT_Fluid.java
+++ /dev/null
@@ -1,14 +0,0 @@
-package gregtech.api.interfaces.fluid;
-
-import net.minecraftforge.fluids.FluidRegistry;
-
-@SuppressWarnings("unused") // API might legitimately expose unused methods within this local project's scope
-public interface IGT_Fluid {
-
- /**
- * Adds this {@link IGT_Fluid} to the {@link FluidRegistry} and internally-implemented registrations
- *
- * @return {@link IGT_RegisteredFluid} The GregTech registered fluid
- */
- IGT_RegisteredFluid addFluid();
-}
diff --git a/src/main/java/gregtech/api/interfaces/fluid/IGT_FluidBuilder.java b/src/main/java/gregtech/api/interfaces/fluid/IGTFluidBuilder.java
index f15b148fcb..2902824873 100644
--- a/src/main/java/gregtech/api/interfaces/fluid/IGT_FluidBuilder.java
+++ b/src/main/java/gregtech/api/interfaces/fluid/IGTFluidBuilder.java
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
import gregtech.api.enums.FluidState;
@SuppressWarnings("unused") // API might legitimately expose unused methods within this local project's scope
-public interface IGT_FluidBuilder {
+public interface IGTFluidBuilder {
/**
* @param colorRGBA The {@code short[]} RGBA color of the {@link Fluid} or {@code null} for no defined RGBA color
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withColorRGBA(final short[] colorRGBA);
+ IGTFluidBuilder withColorRGBA(final short[] colorRGBA);
/**
* @param localizedName The localized name of this {@link IGT_FluidBuilder}
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withLocalizedName(final String localizedName);
+ IGTFluidBuilder withLocalizedName(final String localizedName);
/**
* @param fluidState The {@link FluidState} of this {@link IGT_FluidBuilder}
* @param temperature The Kelvin temperature of this {@link IGT_FluidBuilder}
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withStateAndTemperature(final FluidState fluidState, final int temperature);
+ IGTFluidBuilder withStateAndTemperature(final FluidState fluidState, final int temperature);
/**
* @param stillIconResourceLocation the {@link ResourceLocation} of the still fluid icon
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withStillIconResourceLocation(final ResourceLocation stillIconResourceLocation);
+ IGTFluidBuilder withStillIconResourceLocation(final ResourceLocation stillIconResourceLocation);
/**
* @param flowingIconResourceLocation the {@link ResourceLocation} of the flowing fluid icon
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withFlowingIconResourceLocation(final ResourceLocation flowingIconResourceLocation);
+ IGTFluidBuilder withFlowingIconResourceLocation(final ResourceLocation flowingIconResourceLocation);
/**
* @param textureName The name of the GregTech mod texture of this {@link IGT_FluidBuilder}
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withTextureName(final String textureName);
+ IGTFluidBuilder withTextureName(final String textureName);
/**
* @param fluidBlock the {@link Block} implementation of the {@link IGT_Fluid}
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withFluidBlock(final Block fluidBlock);
+ IGTFluidBuilder withFluidBlock(final Block fluidBlock);
/**
* @param fromFluid the {@link Fluid} to copy the icons from
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withIconsFrom(@Nonnull final Fluid fromFluid);
+ IGTFluidBuilder withIconsFrom(@Nonnull final Fluid fromFluid);
/**
* @param stillIconResourceLocation The {@link ResourceLocation} of the still fluid texture
* @param flowingIconResourceLocation The {@link ResourceLocation} of the flowing fluid texture
* @return {@link IGT_FluidBuilder} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_FluidBuilder withTextures(final ResourceLocation stillIconResourceLocation,
+ IGTFluidBuilder withTextures(final ResourceLocation stillIconResourceLocation,
final ResourceLocation flowingIconResourceLocation);
/**
- * Builds the {@link IGT_Fluid}
+ * Builds the {@link IGTFluid}
*
- * @return the built {@link IGT_Fluid}
+ * @return the built {@link IGTFluid}
*/
- IGT_Fluid build();
+ IGTFluid build();
/**
- * Builds, then adds the {@link IGT_Fluid} to the {@link FluidRegistry}
+ * Builds, then adds the {@link IGTFluid} to the {@link FluidRegistry}
*
- * @return the {@link IGT_Fluid}
+ * @return the {@link IGTFluid}
* @see #build()
- * @see IGT_Fluid#addFluid()
+ * @see IGTFluid#addFluid()
*/
- IGT_RegisteredFluid buildAndRegister();
+ IGTRegisteredFluid buildAndRegister();
}
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
* @param colorRGBA The {@code short[]} RGBA color of the {@link Fluid} or {@code null} for no defined RGBA color
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
- * @param localizedName The localized name of this {@link IGT_FluidBuilder}
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @param localizedName The localized name of this {@link IGTFluidBuilder}
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
- * @param fluidState The {@link FluidState} of this {@link IGT_FluidBuilder}
- * @param temperature The Kelvin temperature of this {@link IGT_FluidBuilder}
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @param fluidState The {@link FluidState} of this {@link IGTFluidBuilder}
+ * @param temperature The Kelvin temperature of this {@link IGTFluidBuilder}
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
* @param stillIconResourceLocation the {@link ResourceLocation} of the still fluid icon
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
* @param flowingIconResourceLocation the {@link ResourceLocation} of the flowing fluid icon
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
- * @param textureName The name of the GregTech mod texture of this {@link IGT_FluidBuilder}
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @param textureName The name of the GregTech mod texture of this {@link IGTFluidBuilder}
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
- * @param fluidBlock the {@link Block} implementation of the {@link IGT_Fluid}
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @param fluidBlock the {@link Block} implementation of the {@link IGTFluid}
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
/**
* @param fromFluid the {@link Fluid} to copy the icons from
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
@@ -10,87 +10,87 @@ import net.minecraftforge.fluids.FluidRegistry;
* @param stillIconResourceLocation The {@link ResourceLocation} of the still fluid texture
* @param flowingIconResourceLocation The {@link ResourceLocation} of the flowing fluid texture
- * @return {@link IGT_FluidBuilder} self for call chaining
+ * @return {@link IGTFluidBuilder} self for call chaining
*/
diff --git a/src/main/java/gregtech/api/interfaces/fluid/IGT_RegisteredFluid.java b/src/main/java/gregtech/api/interfaces/fluid/IGTRegisteredFluid.java
index 181824874c..b2796ed3f7 100644
--- a/src/main/java/gregtech/api/interfaces/fluid/IGT_RegisteredFluid.java
+++ b/src/main/java/gregtech/api/interfaces/fluid/IGTRegisteredFluid.java
@@ -7,54 +7,54 @@ import net.minecraftforge.fluids.FluidContainerRegistry;
import gregtech.api.enums.FluidState;
import gregtech.api.enums.Materials;
-public interface IGT_RegisteredFluid {
+public interface IGTRegisteredFluid {
/**
- * Registers the containers in the {@link FluidContainerRegistry} for this {@link IGT_RegisteredFluid}
+ * Registers the containers in the {@link FluidContainerRegistry} for this {@link IGTRegisteredFluid}
*
* @param fullContainer The full fluid container
* @param emptyContainer The empty fluid container
* @param containerSize The size of the container
* @return The {@link IGT_RegisteredFluid} for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_RegisteredFluid registerContainers(final ItemStack fullContainer, final ItemStack emptyContainer,
+ IGTRegisteredFluid registerContainers(final ItemStack fullContainer, final ItemStack emptyContainer,
final int containerSize);
/**
* Registers the bucket-sized 1000L containers in the {@link FluidContainerRegistry} for this
- * {@link IGT_RegisteredFluid}
+ * {@link IGTRegisteredFluid}
*
* @param fullContainer The full container to associate with this {@link IGT_RegisteredFluid}
* @param emptyContainer The empty container associate with this {@link IGT_RegisteredFluid}
* @return {@link IGT_RegisteredFluid} for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_RegisteredFluid registerBContainers(final ItemStack fullContainer, final ItemStack emptyContainer);
+ IGTRegisteredFluid registerBContainers(final ItemStack fullContainer, final ItemStack emptyContainer);
/**
* Registers the potion-sized 250L containers in the {@link FluidContainerRegistry} for this
- * {@link IGT_RegisteredFluid}
+ * {@link IGTRegisteredFluid}
*
* @param fullContainer The full container to associate with this {@link IGT_RegisteredFluid}
* @param emptyContainer The empty container associate with this {@link IGT_RegisteredFluid}
* @return {@link IGT_RegisteredFluid} self for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_RegisteredFluid registerPContainers(final ItemStack fullContainer, final ItemStack emptyContainer);
+ IGTRegisteredFluid registerPContainers(final ItemStack fullContainer, final ItemStack emptyContainer);
/**
* Updates the {@link Materials}'s fluids from this {@link IGT_RegisteredFluid}'s state
*
* @param material the {@link Materials} to configure based on this {@link IGT_RegisteredFluid} and
* {@link FluidState}
* @return The {@link IGT_RegisteredFluid} for call chaining
*/
@SuppressWarnings("UnusedReturnValue") // Last call in chain, may not use this returned value
- IGT_RegisteredFluid configureMaterials(final Materials material);
+ IGTRegisteredFluid configureMaterials(final Materials material);
/**
- * @return this {@link IGT_RegisteredFluid} cast to {@link Fluid}
+ * @return this {@link IGTRegisteredFluid} cast to {@link Fluid}
*/
Fluid asFluid();
}
@@ -7,54 +7,54 @@ import net.minecraftforge.fluids.FluidContainerRegistry;
* @param emptyContainer The empty fluid container
* @param containerSize The size of the container
- * @return The {@link IGT_RegisteredFluid} for call chaining
+ * @return The {@link IGTRegisteredFluid} for call chaining
*/
@@ -7,54 +7,54 @@ import net.minecraftforge.fluids.FluidContainerRegistry;
*
- * @param fullContainer The full container to associate with this {@link IGT_RegisteredFluid}
- * @param emptyContainer The empty container associate with this {@link IGT_RegisteredFluid}
- * @return {@link IGT_RegisteredFluid} for call chaining
+ * @param fullContainer The full container to associate with this {@link IGTRegisteredFluid}
+ * @param emptyContainer The empty container associate with this {@link IGTRegisteredFluid}
+ * @return {@link IGTRegisteredFluid} for call chaining
*/
@@ -7,54 +7,54 @@ import net.minecraftforge.fluids.FluidContainerRegistry;
*
- * @param fullContainer The full container to associate with this {@link IGT_RegisteredFluid}
- * @param emptyContainer The empty container associate with this {@link IGT_RegisteredFluid}
- * @return {@link IGT_RegisteredFluid} self for call chaining
+ * @param fullContainer The full container to associate with this {@link IGTRegisteredFluid}
+ * @param emptyContainer The empty container associate with this {@link IGTRegisteredFluid}
+ * @return {@link IGTRegisteredFluid} self for call chaining
*/
@@ -7,54 +7,54 @@ import net.minecraftforge.fluids.FluidContainerRegistry;
/**
- * Updates the {@link Materials}'s fluids from this {@link IGT_RegisteredFluid}'s state
+ * Updates the {@link Materials}'s fluids from this {@link IGTRegisteredFluid}'s state
*
@@ -7,54 +7,54 @@ import net.minecraftforge.fluids.FluidContainerRegistry;
*
- * @param material the {@link Materials} to configure based on this {@link IGT_RegisteredFluid} and
+ * @param material the {@link Materials} to configure based on this {@link IGTRegisteredFluid} and
* {@link FluidState}
@@ -7,54 +7,54 @@ import net.minecraftforge.fluids.FluidContainerRegistry;
* {@link FluidState}
- * @return The {@link IGT_RegisteredFluid} for call chaining
+ * @return The {@link IGTRegisteredFluid} for call chaining
*/